@@ -1,7 +1,7 @@
 ################################################################################
 ### Generate a color palette via the colorspace package
 ###
-### Copyright (C) 2007 Michael Hoehle, 2012-2014,2017,2019 Sebastian Meyer
+### Copyright (C) 2007 Michael Hoehle, 2012-2014,2017,2019,2021 Sebastian Meyer
 ###
 ### This file is part of the R package "surveillance",
 ### free software under the terms of the GNU General Public License, version 2,
@@ -16,12 +16,8 @@
                              c=if (use.color) c(90,30) else c(0,0),
                              l=c(50,90), power=c(0.75, 1.2))
     } else if (use.color) {
-        if (getRversion() >= "3.6.0") {
-            grDevices::hcl.colors(n = ncolors, palette = "Heat 2")
-            ## this is the same as colorspace::heat_hcl(ncolors)
-        } else {
-            heat.colors(ncolors)
-        }
+        grDevices::hcl.colors(n = ncolors, palette = "Heat 2")
+        ## this is the same as colorspace::heat_hcl(ncolors)
     } else {
         grey.colors(ncolors)
     }
