@@ -6,16 +6,17 @@
 ### _L_agged power-law kernel f(s) = (||s||/sigma)^-d for ||s|| >= sigma, else 1
 ### Similar to the density of the Pareto distribution (but value 1 for < sigma)
 ###
-### Copyright (C) 2013-2014 Sebastian Meyer
-### $Revision: 777 $
-### $Date: 2014-02-18 12:07:58 +0100 (Die, 18 Feb 2014) $
+### Copyright (C) 2013-2014,2017 Sebastian Meyer
+### $Revision: 1988 $
+### $Date: 2017-10-06 11:04:19 +0200 (Fri, 06. Oct 2017) $
 ################################################################################
 
 
-siaf.powerlawL <- function (nTypes = 1, validpars = NULL)
+siaf.powerlawL <- function (nTypes = 1, validpars = NULL, engine = "C")
 {
     nTypes <- as.integer(nTypes)
     stopifnot(length(nTypes) == 1L, nTypes > 0L)
+    engine <- match.arg(engine, c("C", "R"))
 
     ## for the moment we don't make this type-specific
     if (nTypes != 1) stop("type-specific shapes are not yet implemented")
@@ -37,12 +38,11 @@ siaf.powerlawL <- function (nTypes = 1, validpars = NULL)
         fvals[inPLrange] <- (sLength[inPLrange]/sigma)^-d,
         fvals
         )))
+    environment(f) <- baseenv()
 
     ## numerically integrate f over a polygonal domain
-    F <- function (polydomain, f, logpars, type = NULL, ...)
-        .polyCub.iso(polydomain$bdry, intrfr.powerlawL, logpars, #type,
-                     center=c(0,0), control=list(...))
-    
+    F <- siaf_F_polyCub_iso(intrfr_name = "intrfr.powerlawL", engine = engine)
+
     ## fast integration of f over a circular domain
     Fcircle <- function (r, logpars, type = NULL) {}
     body(Fcircle) <- as.call(c(as.name("{"),
@@ -50,7 +50,7 @@ siaf.powerlawL <- function (nTypes = 1, validpars = NULL)
         expression(
             ## trivial case: radius of integration domain < sigma (=> constant f)
             if (r <= sigma) return(pi * r^2),
-            
+
             ## otherwise, if r > sigma, integration via f^-1
             fofr <- (r/sigma)^-d,
             basevolume <- pi * r^2 * fofr,   # cylinder volume up to height f(r)
@@ -60,6 +60,7 @@ siaf.powerlawL <- function (nTypes = 1, validpars = NULL)
             basevolume + pi * intfinvsq
         )
     ))
+    environment(Fcircle) <- baseenv()
 
     ## derivative of f wrt logpars
     ## CAVE: the derivative of f wrt logsigma is mathematically NaN at x=sigma
@@ -76,21 +77,16 @@ siaf.powerlawL <- function (nTypes = 1, validpars = NULL)
         derivlogd[inPLrange] <- fPL * log(fPL),
         cbind(derivlogsigma, derivlogd)
         )))
+    environment(deriv) <- baseenv()
 
     ## Numerical integration of 'deriv' over a polygonal domain
-    Deriv <- function (polydomain, deriv, logpars, type = NULL, ...)
-    {
-        res.logsigma <- .polyCub.iso(polydomain$bdry,
-                                     intrfr.powerlawL.dlogsigma, logpars, #type,
-                                     center=c(0,0), control=list(...))
-        res.logd <- .polyCub.iso(polydomain$bdry,
-                                 intrfr.powerlawL.dlogd, logpars, #type,
-                                 center=c(0,0), control=list(...))
-        c(res.logsigma, res.logd)
-    }
-    
+    Deriv <- siaf_Deriv_polyCub_iso(
+        intrfr_names = c("intrfr.powerlawL.dlogsigma", "intrfr.powerlawL.dlogd"),
+        engine = engine)
+
     ## simulate from the lagged power law (within a maximum distance 'ub')
     ##simulate <- siaf.simulatePC(intrfr.powerlawL) # <- generic simulator
+    ##environment(simulate) <- getNamespace("surveillance")
     ## faster implementation taking advantage of the constant component:
     simulate <- function (n, logpars, type, ub)
     {
@@ -99,12 +95,12 @@ siaf.powerlawL <- function (nTypes = 1, validpars = NULL)
         ## Sampling via polar coordinates and inversion method
 
         ## random angle
-        theta <- stats::runif(n, 0, 2*pi)
+        theta <- runif(n, 0, 2*pi)
 
         ## sampling radius r
         ## trivial case u < sigma: p(r) \propto r on [0;u]
         if (ub < sigma) {
-            r <- ub * sqrt(stats::runif(n)) # inversion sampling
+            r <- ub * sqrt(runif(n)) # inversion sampling
             ## now rotate each point by a random angle to cover all directions
             return(r * cbind(cos(theta), sin(theta)))
         }
@@ -120,34 +116,29 @@ siaf.powerlawL <- function (nTypes = 1, validpars = NULL)
         mass2 <- sigma^d *
             if (d == 2) log(ub/sigma) else (ub^(2-d)-sigma^(2-d))/(2-d)
         ## probability for r < sigma is mass1/(mass1+mass2) => sample component
-        unir <- stats::runif(n) <= mass1 / (mass1 + mass2)
+        unir <- runif(n) <= mass1 / (mass1 + mass2)
 
         ## samples from the uniform short-range component:
         n1 <- sum(unir)
-        r1 <- sigma * sqrt(stats::runif(n1)) # similar to the case u < sigma
+        r1 <- sigma * sqrt(runif(n1)) # similar to the case u < sigma
 
         ## samples from power-law component: p2(r) \propto r^(-d+1) on [sigma;u]
         ## For d>2 only, we could use VGAM::rpareto(n,sigma,d-2), d=1 is trivial
         n2 <- n - n1
-        r2 <- if (d==1) stats::runif(n2, sigma, ub) else { # inversion sampling
+        r2 <- if (d==1) runif(n2, sigma, ub) else { # inversion sampling
             P2inv <- if (d == 2) { function (z) ub^z * sigma^(1-z) } else {
                 function (z) (z*ub^(2-d) + (1-z)*sigma^(2-d))^(1/(2-d))
             }
-            P2inv(stats::runif(n2))
+            P2inv(runif(n2))
         }
 
         ## put samples from both components together
         r <- c(r1, r2)
-        
+
         ## now rotate each point by a random angle to cover all directions
         r * cbind(cos(theta), sin(theta))
     }
-
-    ## set function environments to the global environment
-    environment(f) <- environment(Fcircle) <-
-        environment(deriv) <- environment(simulate) <- .GlobalEnv
-    ## in F and Deriv we need access to the intrfr-functions
-    environment(F) <- environment(Deriv) <- getNamespace("surveillance")
+    environment(simulate) <- getNamespace("stats")
 
     ## return the kernel specification
     list(f=f, F=F, Fcircle=Fcircle, deriv=deriv, Deriv=Deriv,
@@ -198,8 +189,8 @@ intrfr.powerlawL.dlogd <- function (R, logpars, types = NULL)
     d <- exp(logpars[[2L]])
     pl <- which(R > sigma)
     res <- numeric(length(R))
-    res[pl] <- if (d == 2) -(sigma*log(R[pl]/sigma))^2 else 
-    (sigma^d * R[pl]^(2-d) * (d-2)*d*log(R[pl]/sigma) -
-     d*(sigma^2 - R[pl]^(2-d)*sigma^d)) / (d-2)^2
+    res[pl] <- if (d == 2) -(sigma*log(R[pl]/sigma))^2 else
+        (sigma^d * R[pl]^(2-d) * (d-2)*d*log(R[pl]/sigma) -
+         d*(sigma^2 - R[pl]^(2-d)*sigma^d)) / (d-2)^2
     res
 }
